@@ -1,9 +1,10 @@
 package Mail::Decency::ContentFilter::Core::Cmd;
 
-use Moose;
-extends 'Mail::Decency::ContentFilter::Core';
+use Moose::Role;
+#extends 'Mail::Decency::ContentFilter::Core';
+#with qw/ Mail::Decency::ContentFilter::Core::User /;
 
-use version 0.74; our $VERSION = qv( "v0.1.4" );
+use version 0.74; our $VERSION = qv( "v0.1.6" );
 
 use mro 'c3';
 use Data::Dumper;
@@ -60,21 +61,6 @@ Unlearn wrongly trained SPAM
 
 has cmd_unlearn_spam => ( is => 'rw', isa => 'Str', predicate => 'can_learn_spam' );
 
-=head2 cmd_user : Str
-
-Command for tretreiving a user for the command line variable "%user%" 
-
-=cut
-
-has cmd_user         => ( is => 'rw', isa => 'Str', predicate => 'has_cmd_user' );
-
-=head2 default_user : Str
-
-User which will be used if none could be determined (if not set, the via "to" provided recipient will be used) 
-
-=cut
-
-has default_user     => ( is => 'rw', isa => 'Str', predicate => 'has_default_user' );
 
 =head1 METHODS
 
@@ -85,24 +71,16 @@ Add check params: cmd, check, train and untrain to list of check params
 
 =cut
 
-sub pre_init {
+before init => sub {
     my ( $self ) = @_;
-    
-    # init base, assure we get mime encoded
-    $self->maybe::next::method();
-    
-    if ( $self->has_config_params ) {
-        unshift @{ $self->{ config_params } ||=[] }, qw/
-            cmd_check
-            cmd_learn_ham
-            cmd_unlearn_ham
-            cmd_learn_spam
-            cmd_unlearn_spam
-            cmd_user
-            default_user
-        /;
-    }
-}
+    unshift @{ $self->{ config_params } ||=[] }, qw/
+        cmd_check
+        cmd_learn_ham
+        cmd_unlearn_ham
+        cmd_learn_spam
+        cmd_unlearn_spam
+    /;
+};
 
 
 
@@ -213,71 +191,6 @@ sub cmd_filter {
     return ( 1, $in, $system_result );
 }
 
-
-=head2 get_user
-
-Determines the user for the command line script .. eg "dspam --user %user%"
-
-=cut
-
-sub get_user {
-    my ( $self ) = @_;
-    
-    # getting hit from cache ?
-    my $cache_name = $self->name. "-User-". $self->to;
-    # my $cached = $self->cache->get( $cache_name );
-    # return $cached if $cached;
-    
-    my $user;
-    
-    # using command to retreive home
-    if ( $self->has_cmd_user ) {
-        $user = $self->get_user_by_cmd;
-        $self->logger->debug3( "Got user '$user' from cmd" ) if $user;
-    }
-    
-    # having module fallback method ?
-    elsif ( $self->can( 'get_user_fallback' ) ) {
-        $user = $self->get_user_fallback;
-        $self->logger->debug3( "Got user '$user' from fallback" ) if $user;
-    }
-    
-    # determine fallback user
-    $user ||= $self->has_default_user
-        ? $self->default_user
-        : $self->to
-    ;
-    $self->logger->debug3( "Got final user '$user'" );
-    
-    # write to cache
-    $self->cache->set( $cache_name => $user );
-    
-    
-    
-    return $user;
-}
-
-=head2 get_user_by_cmd
-
-Using the cmd_user command to determine any user/home 
-
-=cut
-
-sub get_user_by_cmd {
-    my ( $self ) = @_;
-    my ( $th, $tn ) = tempfile( $self->server->temp_dir. "/file-XXXXXX", UNLINK => 1 );
-    open my $cmd_fh, '|-', $self->cmd_user. "1>\"$tn\"";
-    print $cmd_fh $self->to;
-    close $cmd_fh;
-    reset $th;
-    my ( $user ) = <$th>;
-    chomp $user;
-    close $th;
-    unlink( $tn ) if -f $tn;
-}
-
-
-
 =head2 build_cmd
 
 Can be overwritte by descendant module
