@@ -2,11 +2,15 @@ package Mail::Decency::ContentFilter::Razor;
 
 use Moose;
 extends qw/
+    Mail::Decency::ContentFilter::Core
+/;
+with qw/
     Mail::Decency::ContentFilter::Core::Cmd
+    Mail::Decency::ContentFilter::Core::User
     Mail::Decency::ContentFilter::Core::Spam
 /;
 
-use version 0.74; our $VERSION = qv( "v0.1.4" );
+use version 0.74; our $VERSION = qv( "v0.1.6" );
 
 use mro 'c3';
 use Data::Dumper;
